#!/bin/sh
# Small script to check the example repository quickly
python array1.py
python array2.py
python array3.py
python array4.py
python attributes1.py
python earray1.py
python earray2.py
python gl-test.py
python objecttree.py
python table1.py
python table2.py
python table-tree.py
python tutorial1-1.py
python tutorial1-2.py
#python tutorial2.py   # This should always fail at the beginning
python vlarray1.py
python vlarray2.py
python nested1.py
python nested-tut.py
